@@ -6,12 +6,15 @@ from abc import ABC, abstractmethod
 
 class __EmptyObject:
     """An empty object. Can be used as an alternative of ``None``."""
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return False
 
-    def __len__(self):
+    def __len__(self) -> int:
         return 0
 
+    def __repr__(self) -> str:
+        return "Empty"
+
 
 EmptyObject: __EmptyObject = __EmptyObject()
 _R = typing.Optional[typing.Union[dict, list, str, bytes]]
@@ -253,7 +256,7 @@ class HTTPRequestBase(ABC):
         :param sticker_ids: List of ID of the stickers.
         """
         if not (content or embeds or sticker_ids):
-            raise ValueError("either content or embed must be passed.")
+            raise ValueError("either content or embed or sticker_ids must be passed.")
         body = {}
         if content is not None:
             body["content"] = content
@@ -603,16 +606,22 @@ class HTTPRequestBase(ABC):
         body = {"name": name, "auto_archive_duration": auto_archive_duration}
         return self.request(f"/channels/{channel_id}/messages/{message_id}/threads", "POST", body, is_json=True, reason_header=reason)
 
-    def start_thread_without_message(self, channel_id, name: str, auto_archive_duration: int, reason: str = None) -> RESPONSE:
+    def start_thread_without_message(self, channel_id, name: str, auto_archive_duration: int, thread_type: int = None, invitable: bool = None, reason: str = None) -> RESPONSE:
         """
         Sends start thread without message request.
 
         :param channel_id: ID of the channel to create thread.
         :param name: Name of the thread channel.
         :param auto_archive_duration: Duration in minute to automatically close after recent activity.
+        :param thread_type: Type of the thread.
+        :param invitable: Whether this thread is invitable.
         :param reason: Reason of the action.
         """
         body = {"name": name, "auto_archive_duration": auto_archive_duration}
+        if thread_type is not None:
+            body["type"] = thread_type
+        if invitable is not None:
+            body["invitable"] = invitable
         return self.request(f"/channels/{channel_id}/threads", "POST", body, is_json=True, reason_header=reason)
 
     def join_thread(self, channel_id) -> RESPONSE:
@@ -742,7 +751,7 @@ class HTTPRequestBase(ABC):
         body = {"name": name, "image": image, "roles": roles}
         return self.request(f"/guilds/{guild_id}/emojis", "POST", body, is_json=True, reason_header=reason)
 
-    def modify_guild_emoji(self, guild_id, emoji_id, name: str, roles: typing.List[str], reason: str = None) -> RESPONSE:
+    def modify_guild_emoji(self, guild_id, emoji_id, name: str = EmptyObject, roles: typing.List[str] = EmptyObject, reason: str = None) -> RESPONSE:
         """
         Sends modify guild emoji request.
 
@@ -752,7 +761,11 @@ class HTTPRequestBase(ABC):
         :param roles: Roles to change.
         :param reason: Reason of the action.
         """
-        body = {"name": name, "roles": roles}
+        body = {}
+        if name is not EmptyObject:
+            body["name"] = name
+        if roles is not EmptyObject:
+            body["roles"] = roles
         return self.request(f"/guilds/{guild_id}/emojis/{emoji_id}", "PATCH", body, is_json=True, reason_header=reason)
 
     def delete_guild_emoji(self, guild_id, emoji_id, reason: str = None) -> RESPONSE:
@@ -840,23 +853,23 @@ class HTTPRequestBase(ABC):
     def modify_guild(self,
                      guild_id,
                      name: str = None,
-                     verification_level: int = None,
-                     default_message_notifications: int = None,
-                     explicit_content_filter: int = None,
-                     afk_channel_id: str = None,
+                     verification_level: int = EmptyObject,
+                     default_message_notifications: int = EmptyObject,
+                     explicit_content_filter: int = EmptyObject,
+                     afk_channel_id: str = EmptyObject,
                      afk_timeout: int = None,
-                     icon: str = None,
+                     icon: str = EmptyObject,
                      owner_id: str = None,
-                     splash: str = None,
-                     discovery_splash: str = None,
-                     banner: str = None,
-                     system_channel_id: str = None,
+                     splash: str = EmptyObject,
+                     discovery_splash: str = EmptyObject,
+                     banner: str = EmptyObject,
+                     system_channel_id: str = EmptyObject,
                      system_channel_flags: int = None,
-                     rules_channel_id: str = None,
-                     public_updates_channel_id: str = None,
-                     preferred_locale: str = None,
+                     rules_channel_id: str = EmptyObject,
+                     public_updates_channel_id: str = EmptyObject,
+                     preferred_locale: str = EmptyObject,
                      features: typing.List[str] = None,
-                     description: str = None,
+                     description: str = EmptyObject,
                      reason: str = None) -> RESPONSE:
         """
         Sends create guild request.
@@ -1296,7 +1309,7 @@ class HTTPRequestBase(ABC):
             params["include_roles"] = ','.join(include_roles)
         return self.request(f"/guilds/{guild_id}/prune", "GET", params=params)
 
-    def begin_guild_prune(self, guild_id, days: int = 7, compute_prune_count: bool = True, include_roles: typing.List[str] = None, reason: str = None) -> RESPONSE:
+    def begin_guild_prune(self, guild_id, days: int = None, compute_prune_count: bool = None, include_roles: typing.List[str] = None, reason: str = None) -> RESPONSE:
         """
         Sends begin guild prune request.
 
@@ -1306,7 +1319,13 @@ class HTTPRequestBase(ABC):
         :param include_roles: Roles to include.
         :param reason: Reason of the action.
         """
-        body = {"days": days, "compute_prune_count": compute_prune_count, "include_roles": include_roles}  # Not sure if params are optional
+        body = {}
+        if days is not None:
+            body["days"] = days
+        if compute_prune_count is not None:
+            body["compute_prune_count"] = compute_prune_count
+        if include_roles is not None:
+            body["include_roles"] = include_roles
         return self.request(f"/guilds/{guild_id}/prune", "POST", body, reason_header=reason)
 
     def request_guild_voice_regions(self, guild_id) -> RESPONSE:
