@@ -1,10 +1,12 @@
 from .application import *
+from .audit_log import *
 from .channel import *
 from .emoji import *
 from .event import *
 from .extras import *
 from .gateway import *
 from .guild import *
+from .guild_template import *
 from .invite import *
 from .permission import *
 from .snowflake import *
