@@ -270,6 +270,9 @@ class Guild(DiscordObjectBase):
         if self.cache:
             return self.get(self.owner_id, "member") or self.get(self.owner_id, "user")
 
+    def __repr__(self):
+        return f"<{self.__class__.__name__} id={self.id} name={self.name}>"
+
 
 class DefaultMessageNotificationLevel(TypeBase):
     ALL_MESSAGES = 0
@@ -380,6 +383,11 @@ class GuildMember:
     def ban(self, *, delete_message_days: int = None, reason: str = None):
         return self.client.create_guild_ban(self.guild_id, self, delete_message_days=delete_message_days, reason=reason)
 
+    @property
+    def id(self) -> typing.Optional[Snowflake]:
+        if self.user:
+            return self.user.id
+
     @property
     def mention(self) -> str:
         if self.user:
