@@ -13,24 +13,24 @@ class ApplicationCommand:
     def __init__(self,
                  name: str,
                  description: str,
-                 command_type: typing.Union[int, "ApplicationCommandTypes"] = 1,
-                 options: typing.List["ApplicationCommandOption"] = None,
-                 default_permission: bool = True,
+                 command_type: typing.Optional[typing.Union[int, "ApplicationCommandTypes"]] = 1,
+                 options: typing.Optional[typing.List["ApplicationCommandOption"]] = None,
+                 default_permission: typing.Optional[bool] = True,
                  **resp):
-        self.id = Snowflake.optional(resp.get("id"))
-        self.type = ApplicationCommandTypes(int(command_type))
-        self.application_id = Snowflake.optional(resp.get("application_id"))
-        self.name = name
-        self.description = description
-        self.options = options or []
-        self.default_permission = default_permission
+        self.id: typing.Optional[Snowflake] = Snowflake.optional(resp.get("id"))
+        self.type: ApplicationCommandTypes = ApplicationCommandTypes(int(command_type))
+        self.application_id: typing.Optional[Snowflake] = Snowflake.optional(resp.get("application_id"))
+        self.name: str = name
+        self.description: str = description
+        self.options: typing.List[ApplicationCommandOption] = options or []
+        self.default_permission: bool = default_permission
         self.__command_creation = not resp
 
-    def __int__(self):
+    def __int__(self) -> int:
         if self.id:
             return int(self.id)
 
-    def to_dict(self):
+    def to_dict(self) -> dict:
         resp = {"name": self.name, "description": self.description, "options": [x.to_dict() for x in self.options], "default_permission": self.default_permission, "type": int(self.type)}
         if self.__command_creation:
             return resp
@@ -56,18 +56,18 @@ class ApplicationCommandOption:
                  option_type: typing.Union["ApplicationCommandOptionType", int],
                  name: str,
                  description: str,
-                 required: bool = False,
-                 choices: typing.List["ApplicationCommandOptionChoice"] = None,
-                 options: typing.List["ApplicationCommandOption"] = None,
+                 required: typing.Optional[bool] = False,
+                 choices: typing.Optional[typing.List["ApplicationCommandOptionChoice"]] = None,
+                 options: typing.Optional[typing.List["ApplicationCommandOption"]] = None,
                  **kw):
-        self.type = ApplicationCommandOptionType(int(option_type))
-        self.name = name
-        self.description = description
-        self.required = required
-        self.choices = choices or []
-        self.options = options or []
+        self.type: ApplicationCommandOptionType = ApplicationCommandOptionType(int(option_type))
+        self.name: str = name
+        self.description: str = description
+        self.required: bool = required
+        self.choices: typing.List[ApplicationCommandOptionChoice] = choices or []
+        self.options: typing.List[ApplicationCommandOption] = options or []
 
-    def to_dict(self):
+    def to_dict(self) -> dict:
         ret = {"type": int(self.type), "name": self.name, "description": self.description, "required": self.required,
                "choices": [x.to_dict() for x in self.choices], "options": [x.to_dict() for x in self.options]}
         if not ret["options"]:
@@ -99,10 +99,10 @@ class ApplicationCommandOptionType(TypeBase):
 
 class ApplicationCommandOptionChoice:
     def __init__(self, name: str, value: typing.Union[str, int, float], **kw):
-        self.name = name
-        self.value = value
+        self.name: str = name
+        self.value: typing.Union[str, int, float] = value
 
-    def to_dict(self):
+    def to_dict(self) -> dict:
         return {"name": self.name, "value": self.value}
 
     @classmethod
@@ -115,23 +115,23 @@ class GuildApplicationCommandPermissions:
     RESPONSE_AS_LIST = typing.Union[typing.List["GuildApplicationCommandPermissions"], typing.Awaitable[typing.List["GuildApplicationCommandPermissions"]]]
 
     def __init__(self, resp: dict):
-        self.id = Snowflake(resp["id"])
-        self.application_id = Snowflake(resp["application_id"])
-        self.guild_id = Snowflake(resp["guild_id"])
-        self.permissions = [ApplicationCommandPermissions.create(x) for x in resp["permissions"]]
+        self.id: Snowflake = Snowflake(resp["id"])
+        self.application_id: Snowflake = Snowflake(resp["application_id"])
+        self.guild_id: Snowflake = Snowflake(resp["guild_id"])
+        self.permissions: typing.List[ApplicationCommandPermissions] = [ApplicationCommandPermissions.create(x) for x in resp["permissions"]]
 
 
 class ApplicationCommandPermissions:
     def __init__(self,
-                 target: typing.Union[int, Role, User],
+                 target: typing.Union[Role.TYPING, User.TYPING],
                  permission_type: typing.Union[int, "ApplicationCommandPermissionType"],
                  permission: bool,
                  **kw):
-        self.id = Snowflake.ensure_snowflake(int(target))
-        self.type = ApplicationCommandPermissionType(int(permission_type))
-        self.permission = permission
+        self.id: typing.Optional[Snowflake] = Snowflake.ensure_snowflake(int(target))
+        self.type: ApplicationCommandPermissionType = ApplicationCommandPermissionType(int(permission_type))
+        self.permission: bool = permission
 
-    def to_dict(self):
+    def to_dict(self) -> dict:
         return {"id": str(self.id), "type": int(self.type), "permission": self.permission}
 
     @classmethod
@@ -147,8 +147,8 @@ class ApplicationCommandPermissionType(TypeBase):
 
 
 class ApplicationCommandInteractionDataOption:
-    def __init__(self, resp):
-        self.name = resp["name"]
-        self.type = ApplicationCommandOptionType(resp["type"])
-        self.value = resp.get("value")
-        self.options = [ApplicationCommandInteractionDataOption(x) for x in resp.get("options", [])]
+    def __init__(self, resp: dict):
+        self.name: str = resp["name"]
+        self.type: ApplicationCommandOptionType = ApplicationCommandOptionType(resp["type"])
+        self.value: typing.Optional = resp.get("value")
+        self.options: typing.List[ApplicationCommandInteractionDataOption] = [ApplicationCommandInteractionDataOption(x) for x in resp.get("options", [])]
