@@ -70,6 +70,9 @@ class Webhook:
     def send(self):
         return self.execute
 
+    def __repr__(self) -> str:
+        return f"<{self.__class__.__name__} id={self.id} name={self.name}>"
+
 
 class WebhookTypes(TypeBase):
     INCOMING = 1
